@@ -118,14 +118,16 @@ pkg_resources.require("simplejson>=2.1.0")
 
 from simplejson import *
 
-__version__ = '2.1.1'
-__all__ = [
-    'dump', 'dumps', 'load', 'loads',
-    'JSONDecoder', 'JSONDecodeError', 'JSONEncoder',
-    'OrderedDict',
-]
-
-__author__ = 'Bob Ippolito <bob@redivi.com>'
+import simplejson
+__version__ = simplejson.__version__
+__all__ = simplejson.__all__
+# The unit tests rely on .encoder and .decoder, and although they are not
+# included in simplejson.__all__ they are still attributes of the simplejson
+# package since they are modules within it.
+from simplejson import encoder, decoder, scanner
+__all__.extend(['encoder', 'decoder', 'scanner'])
+__author__ = simplejson.__author__
+del simplejson
 
 from decimal import Decimal
 
